======================
Command-line interface
======================


.. _sec_compress:

dclab-compress
--------------

.. simple_argparse::
   :module: dclab.cli
   :func: compress_parser
   :prog: dclab-compress


.. _sec_condense:

dclab-condense
--------------

.. simple_argparse::
   :module: dclab.cli
   :func: condense_parser
   :prog: dclab-condense


.. _sec_join:

dclab-join
----------

.. simple_argparse::
   :module: dclab.cli
   :func: join_parser
   :prog: dclab-join


.. _sec_tdms2rtdc:

dclab-tdms2rtdc
---------------

.. simple_argparse::
   :module: dclab.cli
   :func: tdms2rtdc_parser
   :prog: dclab-tdms2rtdc
    

.. _sec_verify_dataset:

dclab-verify-dataset
--------------------

.. simple_argparse::
   :module: dclab.cli
   :func: verify_dataset_parser
   :prog: dclab-verify-dataset
